Module sparse::dok[][src]

Dictionary Of Keys (DOK) format sparse matrix.

Structs

DokMat

Dictionary Of Keys (DOK) format sparse matrix.

Entries

An iterator over the entries of a DOK matrix.

EntriesMut

A mutable iterator over the entries of a DOK matrix.

Indices

An iterator over the indices of a DOK matrix.

IntoEntries

An owning iterator over the entries of a DOK matrix.

Values

An iterator over the values of a DOK matrix.

ValuesMut

A mutable iterator over the values of a DOK matrix.