resparse

Function resparse 

pub fn resparse(
    sparse_file: SparseFileWriter,
    max_download_size: u64,
) -> Result<Vec<SparseFileWriter>, SparseError>
Takes a sparse_file and breaks it into multiple SparseFileWriter slices whose serialized file size will not exceed max_download_size.

Arguments

  • sparse_file - The sparse file writer containing chunk definitions to resparse.
  • max_download_size - Maximum size in bytes for each resparsed slice.

Errors

Returns SparseError::MaxDownloadSizeTooSmall if max_download_size is less than or equal to the block size ([BLK_SIZE]).