resparse_sparse_img_writers

Function resparse_sparse_img_writers 

pub fn resparse_sparse_img_writers<R: Read + Seek>(
    reader: &mut SparseReader<R>,
    max_download_size: u64,
) -> Result<Vec<SparseFileWriter>, SparseError>
Takes a provided reader and generates a set of SparseFileWriters representing the resparsed slices with the provided max_download_size constraining slice size.

Arguments

  • reader - The sparse reader of an existing sparse file.
  • max_download_size - Maximum size in bytes that can be downloaded by the device for each slice.

Errors

Returns SparseError::MaxDownloadSizeTooSmall if max_download_size is less than or equal to the block size ([BLK_SIZE]).